#
# spec file for package python-vispy
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without  ext_deps
%define skip_python2 1
Name:           python-vispy
Version:        0.6.4
Release:        bp154.1.78
Summary:        Interactive visualization in Python
License:        BSD-3-Clause
URL:            https://github.com/vispy/vispy
Source:         https://files.pythonhosted.org/packages/source/v/vispy/vispy-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module setuptools_scm_git_archive}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  jupyter-notebook-filesystem
BuildRequires:  python-rpm-macros
Requires:       fontconfig
Requires:       python-numpy
Requires:       python-qt5
Recommends:     python-PySDL2
Recommends:     python-imageio
Recommends:     python-jupyter_ipython
Recommends:     python-networkx
Recommends:     python-opengl
Recommends:     python-opengl-accelerate
Recommends:     python-pyglet
Recommends:     python-pypng
Recommends:     python-scipy
# SECTION test requirements
BuildRequires:  %{python_module PySDL2}
BuildRequires:  %{python_module glfw}
BuildRequires:  %{python_module imageio}
BuildRequires:  %{python_module jupyter_ipython}
BuildRequires:  %{python_module networkx}
BuildRequires:  %{python_module opengl}
BuildRequires:  %{python_module pyglet}
BuildRequires:  %{python_module qt5}
BuildRequires:  %{python_module scipy}
BuildRequires:  fontconfig
%if %{with ext_deps}
BuildRequires:  %{python_module cassowary}
BuildRequires:  %{python_module decorator}
BuildRequires:  %{python_module freetype-py}
BuildRequires:  %{python_module husl}
BuildRequires:  %{python_module pypng}
BuildRequires:  %{python_module six}
%endif
# /SECTION
%if %{with ext_deps}
Requires:       python-cassowary
Requires:       python-decorator
Requires:       python-freetype-py
Requires:       python-husl
Requires:       python-pypng
Requires:       python-six
%endif
%python_subpackages

%description
Vispy is an interactive 2D/3D data visualization library. It leverages Graphics
Processing Units through the OpenGL library to display large datasets.

%package     -n jupyter-vispy
Summary:        Interactive visualization in the Jupyter notebook
Requires:       jupyter-notebook
Requires:       python3-vispy = %{version}

%description -n jupyter-vispy
Vispy is an interactive 2D/3D data visualization library. It leverages Graphics
Processing Units through the OpenGL library to display large datasets.

This package provides the jupyter notebook extension.

%prep
%setup -q -n vispy-%{version}
%if %{with ext_deps}
rm -rf vispy/ext/_bundled
%endif
sed -i -e '/^#!\//, 1d' vispy/glsl/build-spatial-filters.py vispy/util/transforms.py vispy/visuals/collections/util.py

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%python_build

%install
%python_install
%jupyter_move_config
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitearch}/*

%files -n jupyter-vispy
%license LICENSE.txt
%config %{_jupyter_nb_notebook_confdir}/vispy.json
%{_jupyter_nbextension_dir}/vispy/

%changelog
* Mon Jun  8 2020 Tomáš Chvátal <tchvatal@suse.com>
- Disable py2 build due to missing deps
* Wed Feb  5 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.6.4
  + Enhancements
  * Filter unnecessary QSocketNotifier warning when using QtConsole
  * FIX: Nest triangle and skimage imports
  * Switch to setuptools_scm version.py usage to avoid import overhead
  + Fixed bugs
  * Skip bad font in test_font
- Update to 0.6.3
  + Enhancements
  * Improve AxisVisual visual by providing property getters and setters
  * Fix MarkerVisual scaling when rotating in 3D space
  + Fixed bugs
  * Fix string formatting of array shape
  * Fix texture alignment to use data itemsize
  * Fix shader version handling in webgl backend
  * Fix 2D mesh bounds IndexError when viewed in 3D
  * Fix xaxis labels being wrong initially in PlotWidget
  * Various bug fixes related to AxisVisual
  * Fixed a bug in linking two flycameras
  + Merged pull requests
  * Fix additional numpy warnings when dealing with dtypes of size 1
* Tue Nov 19 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.16.2
  + Enhancements
  * Switch to setuptools_scm for automatic version numbering
  * Improve PanZoom camera performance when non-+z direction is used
  + Fixed bugs
  * Fix Python 3.8 compatibility in Canvas 'keys' update
  * Fix VolumeVisual modifying user provided data in-place
  * Fix depth buffer precision
  * Volume visual has unset variable texture2D\_LUT
  * Fix MarkersVisual.set_data crash when pos is None
  * Fix numpy futurewarning in dtype creation
* Fri Aug  2 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.16.1
  * Fix discrete colormap ordering (#1668)
  * Fix various examples (#1671, #1676)
  * Fix Jupyter extension zoom direction (#1679)
* Tue Jul 23 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.16.0
  * Update PyQt5/PySide2 to use newer GL API
  * Update to PyQt5 as default backend
  * New Cython-based text rendering option
  * New WindbarbVisual
  * Improved JupyterLab/Notebook widget (experimental)
  * Fix various memory leaks
  * Various optimizations and bug fixes
- Add jupyter subpackage
* Wed Apr 17 2019 Todd R <toddrme2178@gmail.com>
- Switch to the qt5 backend.
* Thu Nov  1 2018 Todd R <toddrme2178@gmail.com>
- Update to version 0.15.3
  * Workaround matplotlib 2.2 dropping _cntr private module
  * Try appveyor SSL settings for fixing https download
  * Fix buffer due to unsupported numpy feature
* Sat Mar  3 2018 jengelh@inai.de
- Compact description.
* Thu Jan 18 2018 toddrme2178@gmail.com
- Update to version 0.15.2
  * Fix PyPI packaging to include LICENSE.txt
  * Fix initial axis limits in PlotWidget (#1386)
  * Fix zoom event position in Pyglet backend (#1388)
  * Fix camera importing (#1389, #1172)
  * Refactor `EllipseVisual` and `RectangleVisual` (#1387, #1349)
  * Fix `one_scene_four_cams.py` example (#1391, #1124)
  * Add `two_qt_widgets.py` example (#1392, #1298)
  * Fix order of alignment values for proper processing (#1395, #641)
* Fri Oct 20 2017 toddrme2178@gmail.com
- initial version
